<?php
/**
 * $Horde: nag/search.php,v 1.5.2.3 2003/01/03 12:48:45 jan Exp $
 *
 * Copyright 2001-2003 Jon Parise <jon@horde.org>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

define('NAG_BASE', dirname(__FILE__));
require_once NAG_BASE . '/lib/base.php';

$title = _("Search");
$js_onLoad = null;
require NAG_TEMPLATES . '/common-header.inc';
require NAG_BASE . '/menu.php';
$notification->notify();
require NAG_TEMPLATES . '/search/begin.inc';
require NAG_TEMPLATES . '/search/search.inc';
require NAG_TEMPLATES . '/search/end.inc';
require NAG_TEMPLATES . '/common-footer.inc';
